Discover Packages
github.com/sttts/kc
internal
overlay
package
Version:
v0.8.0
Opens a new window with list of versions in this module.
Published: Nov 30, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Composite merges and flattens the background and foreground views into a single view.
Ported from rmhubbert/bubbletea-overlay (MIT), adapted for internal use.
type Model struct {
Foreground viewer
Background viewer
XPosition Position
YPosition Position
XOffset int
YOffset int
}
Model composes Foreground over Background at the requested position/offsets.
Position represents a relative offset in the TUI. There are five possible values; Top, Right,
Bottom, Left, and Center.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.